@@ -1,22 +1,36 @@
 use std::env;
 use std::fs;
 use std::fs::File;
-use std::io::Read;
 use std::path::Path;
 
-use sourcemap::ram_bundle::{split_ram_bundle, RamBundle};
+use sourcemap::ram_bundle::{split_ram_bundle, RamBundle, RamBundleType};
 use sourcemap::SourceMapIndex;
 
+const USAGE: &str = "
+Usage:
+    ./split_ram_bundle RAM_BUNDLE SOURCEMAP OUT_DIRECTORY
+
+This example app splits the given RAM bundle and the sourcemap into a set of
+source files and their sourcemaps.
+
+Both indexed and file RAM bundles are supported.
+";
+
 fn main() -> Result<(), Box<std::error::Error>> {
     let args: Vec<_> = env::args().collect();
     if args.len() < 4 {
-        panic!("Usage: ./split_ram_bundle RAM_BUNDLE SOURCEMAP OUT_DIRECTORY");
+        println!("{}", USAGE);
+        std::process::exit(1);
     }
 
-    let mut bundle_file = File::open(&args[1])?;
-    let mut bundle_data = Vec::new();
-    bundle_file.read_to_end(&mut bundle_data)?;
-    let ram_bundle = RamBundle::parse(&bundle_data).unwrap();
+    let bundle_path = Path::new(&args[1]);
+    let ram_bundle = RamBundle::parse_indexed_from_path(bundle_path)
+        .or_else(|_| RamBundle::parse_unbundle_from_path(bundle_path))?;
+
+    match ram_bundle.bundle_type() {
+        RamBundleType::Indexed => println!("Indexed RAM Bundle detected"),
+        RamBundleType::Unbundle => println!("File RAM Bundle detected"),
+    }
 
     let sourcemap_file = File::open(&args[2])?;
     let ism = SourceMapIndex::from_reader(sourcemap_file).unwrap();
@@ -41,6 +55,7 @@ fn main() -> Result<(), Box<std::error::Error>> {
         let out_sm = File::create(output_directory.join(sourcemap_name))?;
         sm.to_writer(out_sm)?;
     }
+    println!("Done.");
 
     Ok(())
 }
