@@ -1,5 +1,6 @@
 use std::borrow::Cow;
 use std::cell::RefCell;
+use std::fmt;
 use std::slice;
 use std::str;
 
@@ -150,6 +151,14 @@ impl<'a> Clone for SourceView<'a> {
     }
 }
 
+impl<'a> fmt::Debug for SourceView<'a> {
+    fn fmt(&self, f: &mut fmt::Formatter) -> fmt::Result {
+        f.debug_struct("SourceView")
+            .field("source", &self.source())
+            .finish()
+    }
+}
+
 unsafe fn make_str<'a>(tup: (*const u8, usize)) -> &'a str {
     let (data, len) = tup;
     str::from_utf8_unchecked(slice::from_raw_parts(data, len))
@@ -236,7 +245,7 @@ impl<'a> SourceView<'a> {
             }
 
             let mut off_end = off;
-            while let Some(c) = char_iter.next() {
+            for c in char_iter {
                 if idx >= (col + span) as usize {
                     break;
                 }
@@ -314,6 +323,7 @@ impl<'a> SourceView<'a> {
 }
 
 #[test]
+#[allow(clippy::cyclomatic_complexity)]
 fn test_minified_source_view() {
     let view = SourceView::new("a\nb\nc");
     assert_eq!(view.get_line(0), Some("a"));
